# sageodata_db

SA Geodata database querying tool/wrapper/library for Python

## How to use

Check out complete documentation at:

file:///R:/dfw_cbd/projects/projects_gw/State/Groundwater_Toolbox/Python/wheels/docs/sageodata_db/latest_github/index.html

## Install

Run this in Command Prompt:

```
c:\> pip install sageodata_db
```

To update to the latest version:

```
c:\> pip install -U sageodata_db
```

## License

All rights reserved DEW 2023

